##########
.gitignore
##########

A ``.gitignore`` file is used in Git to specify files and directories that should be ignored by Git when tracking changes in a repository. This file is particularly useful when you have files or directories in your project that you don't want to include in version control. By defining patterns in the ``.gitignore file``, you can ensure that Git ignores those files and doesn't consider them for commits.

.. tip::
    There are websites out there that provide you to automatically generate .gitignore. For example, you can use this: https://www.toptal.com/developers/gitignore